pub fn no_cache() -> SetResponseHeaderLayer<HeaderValue>Expand description
Returns a layer that sets Cache-Control: no-cache, no-store, must-revalidate
if the response does not already include a Cache-Control header.
pub fn no_cache() -> SetResponseHeaderLayer<HeaderValue>Returns a layer that sets Cache-Control: no-cache, no-store, must-revalidate
if the response does not already include a Cache-Control header.