pub trait IntoMapRequestResult<B>: Sealed<B> {
// Required method
fn into_map_request_result(self) -> Result<Request<B>, Response<Body>>;
}Expand description
Trait implemented by types that can be returned from map_request,
map_request_with_state.
This trait is sealed such that it cannot be implemented outside this crate.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".